@@ -4,7 +4,7 @@
 modname = 'vcreview'
 distname = 'cubicweb-vcreview'
 
-numversion = (1, 3, 1)
+numversion = (2, 0, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -19,8 +19,8 @@ classifiers = [
            'Programming Language :: JavaScript',
     ]
 
-__depends__ =  {'cubicweb': '>= 3.17.0',
-                'cubicweb-vcsfile': '>= 1.12.1',
+__depends__ =  {'cubicweb': '>= 3.19.0',
+                'cubicweb-vcsfile': '>= 2.0.0',
                 'cubicweb-comment': '>= 1.8.0',
                 'cubicweb-task': None,
                 'cubicweb-nosylist': None,
@@ -44,7 +44,7 @@ data_files = [
     [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
     ]
 # check for possible extended cube layout
-for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'wdoc', 'i18n', 'migration'):
+for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'wdoc', 'i18n', 'migration', 'hgext'):
     if isdir(dname):
         data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
 # Note: here, you'll need to add subdirectories if you want
