@@ -21,7 +21,7 @@ from logilab.common.decorators import monkeypatch
 
 from cubicweb.entities import AnyEntity
 from cubicweb.view import EntityAdapter
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 from cubes.comment import entities as comment
 from cubes.task import entities as task
