@@ -27,6 +27,7 @@ from yams.buildobjs import (EntityType,
 
 from cubicweb.schema import (WorkflowableEntityType,
                              RQLConstraint,
+                             RQLVocabularyConstraint,
                              RRQLExpression)
 
 from cubes.vcsfile.schema import Repository
@@ -99,7 +100,7 @@ class patch_reviewer(RelationDefinition):
         }
     subject = 'Patch'
     object = 'CWUser'
-    constraints = [RQLConstraint('EXISTS(O in_group G, G name "reviewers") '
+    constraints = [RQLVocabularyConstraint('EXISTS(O in_group G, G name "reviewers") '
                                  'OR EXISTS(S patch_revision RE, '
                                  '          RE from_repository R, '
                                  '          R repository_reviewer O)')]
@@ -115,7 +116,7 @@ class patch_committer(RelationDefinition):
         }
     subject = 'Patch'
     object = 'CWUser'
-    constraints = [RQLConstraint('EXISTS(O in_group G, G name "committers") '
+    constraints = [RQLVocabularyConstraint('EXISTS(O in_group G, G name "committers") '
                                  'OR EXISTS(S patch_revision RE, RE from_repository R, R repository_committer O)')]
 
 
