@@ -25,24 +25,16 @@ from logilab.common.decorators import classproperty
 
 from cubicweb.devtools import testlib
 
-from cubes.vcsfile.testutils import init_vcsrepo
+from cubes.vcsfile.testutils import init_vcsrepo, HGRCMixin
 
-class AutomaticWebTest(testlib.AutomaticWebTest):
+class AutomaticWebTest(HGRCMixin, testlib.AutomaticWebTest):
     no_auto_populate = ('Repository',
                         'Revision',
-                        'VersionedFile',
-                        'VersionContent',
-                        'DeletedVersionContent',
                         'Patch',
                         'Comment',
                         'InsertionPoint',)
-    ignored_relations = set(('at_revision',
-                             'parent_revision',
+    ignored_relations = set(('parent_revision',
                              'from_repository',
-                             'from_revision',
-                             'content_for',
-                             'vc_copy',
-                             'vc_rename',
                              'patch_revision',
                              'nosy_list',
                              'comments',
@@ -78,19 +70,18 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
         return osp.join(cls.__tmpdir, u'repo')
 
     # XXX presetup
-    def custom_populate(self, how_many, cursor):
-        req = self.request()
-        self.create_user(req, 'Babar', ('users', 'reviewers', 'committers'),
+    def custom_populate(self, how_many, cnx):
+        self.create_user(cnx, 'Babar', ('users', 'reviewers', 'committers'),
                          email=u'babar@jungle.net')
-        self.create_user(req, 'Victor', ('users', 'reviewers'),
+        self.create_user(cnx, 'Victor', ('users', 'reviewers'),
                          email=u'victor@ratax.es')
-        self.commit()
-        req.create_entity('Repository',
+        cnx.commit()
+        cnx.create_entity('Repository',
                           type=u'mercurial',
                           encoding=u'utf8',
-                          path=self.full_repo_path,
+                          local_cache=self.full_repo_path,
                           has_review=True)
-        self.commit()
+        cnx.commit()
         init_vcsrepo(self.repo)
 
 AutomaticWebTest.repo_path = osp.join(AutomaticWebTest.datadir,
