@@ -18,7 +18,8 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.web import uicfg, formwidgets as wdg
+from cubicweb.web import formwidgets as wdg
+from cubicweb.web.views import uicfg
 
 _affk = uicfg.autoform_field_kwargs
 _abaa = uicfg.actionbox_appearsin_addmenu
