@@ -20,13 +20,13 @@ _ = unicode
 
 from logilab.mtconverter import xml_escape
 
-from cubicweb.selectors import (is_instance, relation_possible,
+from cubicweb.predicates import (is_instance, relation_possible,
                                 score_entity, match_form_params)
 from cubicweb import tags, uilib, view
-from cubicweb.web import uicfg, component, form, formwidgets as wdg
+from cubicweb.web import component, form, formwidgets as wdg
 from cubicweb.view import EntityView
 from cubicweb.web.views import (workflow, idownloadable, ajaxedit,
-                                forms, formrenderers)
+                                forms, formrenderers, uicfg)
 
 from cubes.comment import views as comment
 from cubes.vcreview.site_cubicweb import COMPONENT_CONTEXT
