@@ -18,7 +18,7 @@
 __docformat__ = "restructuredtext en"
 
 from cubicweb.web import facet
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 class PatchRepositoryFacet(facet.RQLPathFacet):
     __regid__ = 'vcreview.patch_repository'
@@ -55,3 +55,22 @@ class PatchCommitterFacet(facet.RelationFacet):
     rtype = 'patch_committer'
     role = 'subject'
     target_attr = 'login'
+
+class PatchHasOpenTasksFacet(facet.RQLPathFacet):
+    __regid__ = 'vcreview.has_open_tasks'
+    __select__ = is_instance('Patch')
+    title = 'Tasks'
+    path = ['X has_activity A', 'A in_state ST', 'ST name "todo"',
+            'A title T']
+    filter_variable = 'A'
+    label_variable = 'T'
+
+class PatchHasOpenTasksInInsertionPointsFacet(facet.RQLPathFacet):
+    __regid__ = 'vcreview.open_tasks_in_insertion_points'
+    __select__ = is_instance('Patch')
+    title = 'Tasks (inlined)'
+    path = ['X patch_revision R', 'IP point_of R',
+            'IP has_activity A', 'A in_state ST', 'ST name "todo"',
+            'A title T']
+    filter_variable = 'A'
+    label_variable = 'T'
