@@ -19,11 +19,11 @@ __docformat__ = "restructuredtext en"
 
 from datetime import datetime
 
-from cubicweb.selectors import (is_instance, rql_condition, attribute_edited,
+from cubicweb.predicates import (is_instance, rql_condition, attribute_edited,
                                 match_transition, match_user_groups)
 from cubicweb.uilib import cut
-from cubicweb.web import uicfg, formfields
-from cubicweb.web.views import workflow, editviews, autoform
+from cubicweb.web import formfields
+from cubicweb.web.views import workflow, editviews, autoform, uicfg
 
 _affk = uicfg.autoform_field_kwargs
 
