@@ -21,11 +21,10 @@ _ = unicode
 from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
-from cubicweb.selectors import score_entity, is_instance
+from cubicweb.predicates import score_entity, is_instance
 from cubicweb.view import EntityView
 from cubicweb.schema import display_name
-from cubicweb.web import uicfg
-from cubicweb.web.views import tabs, primary, ibreadcrumbs
+from cubicweb.web.views import tabs, primary, ibreadcrumbs, uicfg
 
 from cubes.vcsfile.views import primary as vcsfile
 from cubes.vcreview.views import final_patch_states_rql
