@@ -22,7 +22,7 @@ from logilab.common.decorators import cached
 from logilab.mtconverter import xml_escape
 
 from cubicweb import tags, view
-from cubicweb.selectors import is_instance, rql_condition, anonymous_user
+from cubicweb.predicates import is_instance, rql_condition, anonymous_user
 from cubicweb.uilib import domid
 from cubicweb.web import component
 from cubicweb.web.views import tableview
